import dataset from "assets/dataset_small.json"
import { collection, getDocs, type DocumentData } from "firebase/firestore/lite"

import type { PlasmoMessaging } from "@plasmohq/messaging"

// import initialized db instance
import { db } from "~background"

interface data_small {
  brand: string
  COUNTRY: string
  environmental_total: number
  supplychain_total: number
  social_total: number
}

interface url_data {
  name: string
  url: string
}

const data: data_small[] = dataset

async function queryUrls() {
  const urlsCollection = collection(db, "urls")
  const urlsSnapshot = await getDocs(urlsCollection)
  const urlsList = urlsSnapshot.docs.map((doc) => doc.data())
  return urlsList
}

function ifExists(tokens: string) {
  const answer = data.find((brand) =>
    tokens.toLowerCase().includes(brand.brand.toLowerCase())
  )
  return answer
}

function getAnswers(tokens: string, validUrl: DocumentData) {
  let secondAnswer
  let mainAnswer: data_small = ifExists(tokens)
  if (validUrl.name.toLowerCase().includes(mainAnswer.brand.toLowerCase())) {
    secondAnswer = mainAnswer
    mainAnswer = ifExists(tokens.replace(secondAnswer.brand, ""))
  } else {
    secondAnswer = ifExists(validUrl.name)
  }
  return { mainAnswer, secondAnswer }
}

const handler: PlasmoMessaging.MessageHandler = async (req, res) => {
  const urls = await queryUrls()
  const queryOptions = { active: true, lastFocusedWindow: true }
  const [tab]: chrome.tabs.Tab[] = await chrome.tabs.query(queryOptions)
  const validUrl = urls.find((doc) => tab.url.includes(doc.url))
  const tokens: string = await tab.title
  const answer = getAnswers(tokens, validUrl)
  res.send({
    answer,
    validUrl
  })
}

export default handler
